Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(159)

Unified Diff: Source/bindings/v8/NPV8Object.h

Issue 293963003: Remove ScriptObject (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/bindings/v8/NPV8Object.cpp » ('j') | Source/bindings/v8/ScriptValue.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/bindings/v8/NPV8Object.h
diff --git a/Source/bindings/v8/NPV8Object.h b/Source/bindings/v8/NPV8Object.h
index 435f778d1518faf4766ae662b0b9a727e0394273..ddb9537d5385352d7ee000ac0cff9c301f0d0d9f 100644
--- a/Source/bindings/v8/NPV8Object.h
+++ b/Source/bindings/v8/NPV8Object.h
@@ -46,7 +46,7 @@ static const int npObjectInternalFieldCount = v8DefaultWrapperInternalFieldCount
const WrapperTypeInfo* npObjectTypeInfo();
// A V8NPObject is a NPObject which carries additional V8-specific information.
// It is created with npCreateV8ScriptObject() and deallocated via the deallocate
// method in the same way as other NPObjects.
struct V8NPObject {
WTF_MAKE_NONCOPYABLE(V8NPObject);
@@ -64,7 +64,7 @@ struct PrivateIdentifier {
bool isString;
};
-NPObject* npCreateV8ScriptObject(NPP, v8::Handle<v8::Object>, DOMWindow*, v8::Isolate*);
+NPObject* npCreateV8ScriptValue(NPP, v8::Handle<v8::Object>, DOMWindow*, v8::Isolate*);
NPObject* v8ObjectToNPObject(v8::Handle<v8::Object>);
« no previous file with comments | « no previous file | Source/bindings/v8/NPV8Object.cpp » ('j') | Source/bindings/v8/ScriptValue.h » ('J')
@@ -46,7 +46,7 @@ static const int npObjectInternalFieldCount = v8DefaultWrapperInternalFieldCount
const WrapperTypeInfo* npObjectTypeInfo();
// A V8NPObject is a NPObject which carries additional V8-specific information.
-// It is created with npCreateV8ScriptObject() and deallocated via the deallocate
+// It is created with npCreateV8ScriptValue() and deallocated via the deallocate
// method in the same way as other NPObjects.
struct V8NPObject {

Powered by Google App Engine
This is Rietveld 408576698